@@ -2,12 +2,12 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_appconfig
+from moto import mock_aws
 
 
-@mock_appconfig
+@mock_aws
 class TestHostedConfigurationVersions:
-    def setup_method(self, *args):  # pylint: disable=unused-argument
+    def setup_method(self, *args):
         self.client = boto3.client("appconfig", region_name="us-west-1")
         self.app_id = self.client.create_application(Name="testapp")["Id"]
         self.config_profile_id = self.client.create_configuration_profile(
