@@ -4,7 +4,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_mediaconnect
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 region = "eu-west-1"
@@ -48,6 +48,7 @@ def _create_flow_config(name, **kwargs):
     source_failover_config = kwargs.get("source_failover_config", {})
     sources = kwargs.get("sources", [])
     vpc_interfaces = kwargs.get("vpc_interfaces", [])
+    maintenance = kwargs.get("maintenance", {})
     flow_config = dict(Name=name)
     optional_flow_config = dict(
         AvailabilityZone=availability_zone,
@@ -57,6 +58,7 @@ def _create_flow_config(name, **kwargs):
         SourceFailoverConfig=source_failover_config,
         Sources=sources,
         VpcInterfaces=vpc_interfaces,
+        Maintenance=maintenance,
     )
     for key, value in optional_flow_config.items():
         if value:
@@ -71,7 +73,7 @@ def _check_mediaconnect_arn(type_, arn, name):
     assert _arn_list[-1] == name
 
 
-@mock_mediaconnect
+@mock_aws
 def test_create_flow_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -93,7 +95,22 @@ def test_create_flow_succeeds():
     )
 
 
-@mock_mediaconnect
+@mock_aws
+def test_create_flow_with_maintenance_succeeds():
+    client = boto3.client("mediaconnect", region_name=region)
+    channel_config = _create_flow_config(
+        "test-Flow-2",
+        maintenance={"MaintenanceDay": "Sunday", "MaintenanceStartHour": "02:00"},
+    )
+
+    response = client.create_flow(**channel_config)
+
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+    assert response["Flow"]["Maintenance"]["MaintenanceDay"] == "Sunday"
+    assert response["Flow"]["Maintenance"]["MaintenanceStartHour"] == "02:00"
+
+
+@mock_aws
 def test_create_flow_alternative_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config(
@@ -123,7 +140,7 @@ def test_create_flow_alternative_succeeds():
     )
 
 
-@mock_mediaconnect
+@mock_aws
 def test_list_flows_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     flow_1_config = _create_flow_config("test-Flow-1")
@@ -146,7 +163,7 @@ def test_list_flows_succeeds():
     assert response["Flows"][1]["Status"] == "STANDBY"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_describe_flow_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -159,7 +176,7 @@ def test_describe_flow_succeeds():
     assert describe_response["Flow"]["Name"] == "test-Flow-1"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_delete_flow_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -173,7 +190,7 @@ def test_delete_flow_succeeds():
     assert delete_response["Status"] == "STANDBY"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_start_stop_flow_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -202,7 +219,7 @@ def test_start_stop_flow_succeeds():
     assert describe_response["Flow"]["Status"] == "STANDBY"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_unknown_flow():
     client = boto3.client("mediaconnect", region_name=region)
 
@@ -227,7 +244,7 @@ def test_unknown_flow():
     assert exc.value.response["Error"]["Code"] == "NotFoundException"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_tag_resource_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
 
@@ -239,7 +256,7 @@ def test_tag_resource_succeeds():
     assert list_response["Tags"] == {"Tag1": "Value1"}
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_vpc_interfaces_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -273,7 +290,7 @@ def test_add_flow_vpc_interfaces_succeeds():
     ]
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_vpc_interfaces_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -284,7 +301,7 @@ def test_add_flow_vpc_interfaces_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_remove_flow_vpc_interface_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -316,7 +333,7 @@ def test_remove_flow_vpc_interface_succeeds():
     assert len(describe_response["Flow"]["VpcInterfaces"]) == 0
 
 
-@mock_mediaconnect
+@mock_aws
 def test_remove_flow_vpc_interface_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -329,7 +346,7 @@ def test_remove_flow_vpc_interface_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_outputs_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -352,7 +369,7 @@ def test_add_flow_outputs_succeeds():
     assert outputs == [{"Description": "string", "Name": "string", "Port": 123}]
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_outputs_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -363,7 +380,7 @@ def test_add_flow_outputs_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_output_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -380,7 +397,7 @@ def test_update_flow_output_succeeds():
     assert update_response["Output"]["Description"] == "new description"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_output_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -395,7 +412,7 @@ def test_update_flow_output_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_remove_flow_output_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -407,7 +424,7 @@ def test_remove_flow_output_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_remove_flow_output_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -434,7 +451,7 @@ def test_remove_flow_output_succeeds():
     assert len(describe_response["Flow"]["Outputs"]) == 0
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_sources_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -445,7 +462,7 @@ def test_add_flow_sources_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_add_flow_sources_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -472,7 +489,7 @@ def test_add_flow_sources_succeeds():
     assert len(describe_response["Flow"]["Sources"]) == 1
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_source_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -490,7 +507,7 @@ def test_update_flow_source_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_source_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -524,7 +541,7 @@ def test_update_flow_source_succeeds():
     assert update_response["Source"]["Description"] == "new description"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_grant_flow_entitlements_fails():
     client = boto3.client("mediaconnect", region_name=region)
     flow_arn = "unknown-flow"
@@ -551,7 +568,7 @@ def test_grant_flow_entitlements_fails():
     assert err["Message"] == "flow with arn=unknown-flow not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_grant_flow_entitlements_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -594,7 +611,7 @@ def test_grant_flow_entitlements_succeeds():
     assert "Entitlement-C" in entitlement_names
 
 
-@mock_mediaconnect
+@mock_aws
 def test_revoke_flow_entitlement_fails():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -617,7 +634,7 @@ def test_revoke_flow_entitlement_fails():
     assert err["Message"] == "entitlement with arn=some-other-arn not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_revoke_flow_entitlement_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -642,7 +659,7 @@ def test_revoke_flow_entitlement_succeeds():
     assert len(describe_response["Flow"]["Entitlements"]) == 0
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_entitlement_fails():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
@@ -667,7 +684,7 @@ def test_update_flow_entitlement_fails():
     assert err["Message"] == "entitlement with arn=some-other-arn not found"
 
 
-@mock_mediaconnect
+@mock_aws
 def test_update_flow_entitlement_succeeds():
     client = boto3.client("mediaconnect", region_name=region)
     channel_config = _create_flow_config("test-Flow-1")
