@@ -1,5 +1,4 @@
 import json
-import sure  # noqa # pylint: disable=unused-import
 
 import moto.server as server
 
@@ -10,7 +9,10 @@ def test_ssoadmin_list():
 
     headers = {
         "X-Amz-Target": "SWBExternalService.ListAccountAssignments",
-        "User-Agent": "aws-cli/2.2.47 Python/3.8.8 Linux/5.11.0-44-generic exe/x86_64.ubuntu.20 prompt/off command/sso-admin.list-account-assignments",
+        "User-Agent": (
+            "aws-cli/2.2.47 Python/3.8.8 Linux/5.11.0-44-generic exe"
+            "/x86_64.ubuntu.20 prompt/off command/sso-admin.list-account-assignments",
+        ),
     }
     data = {
         "InstanceArn": "arn:aws:sso:::instance/ins-aaaabbbbccccdddd",
@@ -20,5 +22,5 @@ def test_ssoadmin_list():
 
     resp = test_client.post("/", headers=headers, data=json.dumps(data))
 
-    resp.status_code.should.equal(200)
-    json.loads(resp.data).should.equal({"AccountAssignments": []})
+    assert resp.status_code == 200
+    assert json.loads(resp.data) == {"AccountAssignments": [], "NextToken": None}
